#[non_exhaustive]pub struct GetQueryResultsInput {
pub query_execution_id: Option<String>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
pub query_result_type: Option<QueryResultType>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.query_execution_id: Option<String>The unique ID of the query execution.
next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
max_results: Option<i32>The maximum number of results (rows) to return in this request.
query_result_type: Option<QueryResultType>When you set this to DATA_ROWS or empty, GetQueryResults returns the query results in rows. If set to DATA_MANIFEST, it returns the manifest file in rows. Only the query types CREATE TABLE AS SELECT, UNLOAD, and INSERT can generate a manifest file. If you use DATA_MANIFEST for other query types, the query will fail.
Implementations
Sourceimpl GetQueryResultsInput
impl GetQueryResultsInput
Sourcepub fn query_execution_id(&self) -> Option<&str>
pub fn query_execution_id(&self) -> Option<&str>
The unique ID of the query execution.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of results (rows) to return in this request.
Sourcepub fn query_result_type(&self) -> Option<&QueryResultType>
pub fn query_result_type(&self) -> Option<&QueryResultType>
When you set this to DATA_ROWS or empty, GetQueryResults returns the query results in rows. If set to DATA_MANIFEST, it returns the manifest file in rows. Only the query types CREATE TABLE AS SELECT, UNLOAD, and INSERT can generate a manifest file. If you use DATA_MANIFEST for other query types, the query will fail.
Sourceimpl GetQueryResultsInput
impl GetQueryResultsInput
Sourcepub fn builder() -> GetQueryResultsInputBuilder
pub fn builder() -> GetQueryResultsInputBuilder
Creates a new builder-style object to manufacture GetQueryResultsInput.