#[non_exhaustive]pub struct GetQueryResultsOutput {
pub update_count: Option<i64>,
pub result_set: Option<ResultSet>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_count: Option<i64>The number of rows inserted with a CREATE TABLE AS SELECT, INSERT INTO, or UPDATE statement.
result_set: Option<ResultSet>The results of the query execution.
next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Implementations
Sourceimpl GetQueryResultsOutput
impl GetQueryResultsOutput
Sourcepub fn update_count(&self) -> Option<i64>
pub fn update_count(&self) -> Option<i64>
The number of rows inserted with a CREATE TABLE AS SELECT, INSERT INTO, or UPDATE statement.
Sourcepub fn result_set(&self) -> Option<&ResultSet>
pub fn result_set(&self) -> Option<&ResultSet>
The results of the query execution.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourceimpl GetQueryResultsOutput
impl GetQueryResultsOutput
Sourcepub fn builder() -> GetQueryResultsOutputBuilder
pub fn builder() -> GetQueryResultsOutputBuilder
Creates a new builder-style object to manufacture GetQueryResultsOutput.